@@ -1,3 +1,3 @@
-HOST = "api.skylarklabs.ai"
-HTTPS_PROTOCOL = "https://"
+HOST = "3.239.249.26:8000"
+HTTPS_PROTOCOL = "http://"
 WEBSOCKET_AUTH_API = "%s%s/%s" % (HTTPS_PROTOCOL, HOST, "console/web-socket-token/")
