@@ -14,36 +14,42 @@ from skylark.core.lie_detection_stream import LieDetectionStreamClient
 from skylark.core.night_day_stream import NightDayStreamClient
 import time
 from skylark.utils.utils import is_connected
+from threading import Thread
+from skylark.core.multi_stream import MultiStreamer
 
 
 
 
 # user will add authorization token here
-token = "e22a8efa08231e851a5b8b8de45fff9eefc53d4b8ad59ded636fa8bcdcf0713a"
+token = "abcd"
 
 # user will send fps of incoming stream, size of batch that will be formed while processing ,
-# the rate at which sampling is done, and the token
-c = FaceMaskStreamClient(
-	fps=5,
-	batch_size=1,
-	sampling_rate=1,
-	token=token,
-	show_processed_stream=True,
-	save_raw_frames=True,
-	scale_percent=70,
-	quality=40,
-)
-
 
 # user can continue to perform any further tasks as per need
-try:
-	i=0
-	while True:
-			print("in main")
-			print(is_connected())
-			print(str(len(c.frames)))
-			time.sleep(1)
+if __name__ == '__main__':
+    dict = {}
+    dict['service_name'] = 'face_mask'
+    dict['stream_url'] = "rtsp://admin:admin123@203.134.200.170:554/cam/realmonitor?channel=12&subtype=0"
+    dict['fps'] = 5
+    dict['batch_size']=1
+    dict['sampling_rate']=1
+    dict['show_processed_stream']=True
+    dict['save_raw_frames'] = True
+    dict['scale_percent'] = 35
+    dict['quality'] = 40
+    multi_stream = MultiStreamer(token, [dict,])
 
+
+def ready():
+    print("i am ready now")
+try:
+    i=0
+    while True:
+        print("in mian")
+        if len(multi_stream.client) > 1:
+            print("############## heyy got id ###################")
+            print(multi_stream.client[0].response_jsons)
+        time.sleep(1)
 except KeyboardInterrupt:
 	print("exiting")
 	exit()
